.progress-bar {
  height: $progress-bar-height;
  border-radius: $border-radius;
}

.progress {
  overflow: visible;

  &.progress-xs {
    height: $progress-height-xs;
  }
  &.progress-sm {
    height: $progress-height-sm;
  }
  &.progress-lg {
    height: $progress-height-lg;
  }
}
