<footer class="footer pt-3">
  <div class="container-fluid">
    <div class="row align-items-center justify-content-lg-between">
      <div class="col-lg-6">
        <ul class="nav nav-footer justify-content-center justify-content-lg-end">
          <li class="nav-item">
            <a href="https://appseed.us/product/argon-dashboard/flask" class="nav-link text-muted" target="_blank">{{ _("Flask Dashboard Argon") }}</a>
          </li>
          <li class="nav-item">
            <a href="https://github.com/AAA3A-AAA3A" class="nav-link text-muted" target="_blank">{{ _("Adapted for Red-DiscordBot") }}</a>
          </li>
        </ul>
      </div>
      <div class="col-lg-3 mb-lg-0 mb-4">
        <div class="copyright text-end text-sm text-muted">
          &copy; <a href="https://www.creative-tim.com" class="font-weight-bold" target="_blank">{{ _("Creative Tim") }}</a>
          - {{ _("Template created by AppSeed.") }}
        </div>
      </div>
    </div>
  </div>
</footer>
