$fc-event-title-padding-y:      .2rem !default;
$fc-event-title-padding-x:      .3rem !default;

$fc-daygrid-event-border-radius: .35rem !default;
$fc-theme-standard-dark-border-color: rgba($secondary, .3) !default;