$animation-name:        fadeInBottom !default;
$animation-mode:        both !default;
$animation-duration:    1.5s !default;
$transform-scale:       scale(0.6) !default;
$position-left:         18% !default;  
