$choices-box-shadow: $dropdown-box-shadow !default;
$choices-border-radius: .5rem !default;
$choices-animation: .3s cubic-bezier(.23,1,.32,1) !default;
$choices-transition: $dropdown-transition !default;
$choices-transform: perspective(999px) rotateX(-10deg) translateZ(0) translate3d(0px, 37px, 0px) !important !default;
$choices-transform-show: perspective(999px) rotateX(0deg) translateZ(0) translate3d(0,37px,5px) !important !default;
$choices-padding-y: 1rem !default;
$choices-padding-x: .5rem !default;
