// =========================================================
// * Argon Dashboard 2 - v2.0.4
// =========================================================
//
// * Product Page: https://www.creative-tim.com/product/argon-dashboard
// * Copyright 2022 Creative Tim (https://www.creative-tim.com)
//
// Coded by www.creative-tim.com
//
// =========================================================
//
// * The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.

// Bootstrap Functions
@import "argon-dashboard/bootstrap/functions";

// Custom Variables
@import "argon-dashboard/custom/variables";

// Theme Variables
@import "argon-dashboard/variables";

// Bootstrap Core
@import "argon-dashboard/bootstrap/bootstrap";

// Theme Core
@import "argon-dashboard/theme";

// Custom Variables
@import "argon-dashboard/custom/styles";
